"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = require("react");
const events_1 = __importDefault(require("../events"));
const task_runner_1 = require("../task-runner");
const get_element_1 = __importDefault(require("../task-runner/get-element"));
const bind_channel_events_1 = require("../util/bind-channel-events");
const get_tasks_map_1 = __importDefault(require("../tasks/get-tasks-map"));
const get_groups_1 = require("../tasks/get-groups");
function TaskHarness({ getNode, channel, interactions, allowedGroups }) {
    const groups = react_1.useMemo(function merge() {
        return get_groups_1.getGroups({
            allowedGroups,
            interactions: interactions,
        });
    }, [interactions, allowedGroups]);
    const tasks = react_1.useMemo(() => get_tasks_map_1.default(groups), [groups]);
    react_1.useEffect(function setup() {
        function safeEmit(name, args) {
            if (!safeEmit.isEnabled) {
                return;
            }
            channel.emit(name, args);
        }
        safeEmit.isEnabled = true;
        const unbindAll = bind_channel_events_1.bindAll(channel, [
            {
                eventName: events_1.default.START_ALL,
                fn: async function onStartAll({ copies, samples }) {
                    const results = await task_runner_1.runAll({
                        groups,
                        getNode,
                        samples,
                        copies,
                    });
                    safeEmit(events_1.default.FINISH_ALL, { results });
                },
            },
            {
                eventName: events_1.default.START_ONE,
                fn: async function onStartOne({ taskName, copies, samples }) {
                    const task = tasks[taskName];
                    if (task == null) {
                        throw new Error(`Could not find task with id: ${taskName}`);
                    }
                    if (task.type === 'timed' || task.type === 'interaction') {
                        const result = await task_runner_1.runOneTimed({
                            task,
                            getNode,
                            samples,
                            copies,
                        });
                        safeEmit(events_1.default.FINISH_ONE, { taskName, result });
                        return;
                    }
                    if (task.type === 'static') {
                        const result = await task_runner_1.runOneStatic({
                            task,
                            getNode,
                            copies,
                        });
                        safeEmit(events_1.default.FINISH_ONE, { taskName, result });
                        return;
                    }
                },
            },
        ]);
        return function unbind() {
            unbindAll();
            safeEmit.isEnabled = false;
        };
    }, [channel, getNode, interactions, groups, tasks]);
    return get_element_1.default(getNode)();
}
exports.default = TaskHarness;
