"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const react_1 = __importDefault(require("react"));
const tiny_invariant_1 = __importDefault(require("tiny-invariant"));
const error_result_1 = __importDefault(require("./error-result"));
const static_result_1 = __importDefault(require("./static-result"));
const timed_result_1 = __importDefault(require("./timed-result"));
function TaskResult({ task, result, pinned }) {
    if (result == null) {
        return null;
    }
    if (result.type === 'error') {
        return react_1.default.createElement(error_result_1.default, { key: task.name, task: task, result: result });
    }
    if (result.type === 'static') {
        tiny_invariant_1.default(task.type === 'static', `Unexpected task type: ${task.type}`);
        const pin = pinned && pinned.type === 'static' ? pinned : null;
        return react_1.default.createElement(static_result_1.default, { key: task.name, task: task, result: result, pinned: pin });
    }
    if (result.type === 'timed') {
        tiny_invariant_1.default(task.type === 'timed' || task.type === 'interaction', `Unexpected task type: ${task.type}`);
        const pin = pinned && pinned.type === 'timed' ? pinned : null;
        return react_1.default.createElement(timed_result_1.default, { key: task.name, task: task, result: result, pinned: pin });
    }
    console.error('Incorrect data passed to TaskResult', { result, task, pinned });
    return null;
}
exports.default = TaskResult;
