"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const coreEvents = __importStar(require("@storybook/core-events"));
const react_1 = require("@xstate/react");
const react_2 = require("react");
const events_1 = __importDefault(require("../events"));
const bind_channel_events_1 = require("../util/bind-channel-events");
const file_system_1 = require("./file-system");
const pinned_storage_1 = require("./pinned-storage");
function mergeWithResults({ existing, result }) {
    return existing.map((groupResult) => {
        return {
            ...groupResult,
            map: {
                ...groupResult.map,
                [result.taskName]: result,
            },
        };
    });
}
function usePanelMachine(machine, channel) {
    const [state, send, service] = react_1.useMachine(machine);
    react_2.useEffect(function bindChannelEvents() {
        const unsubscribe = bind_channel_events_1.bindAll(channel, [
            {
                eventName: coreEvents.STORY_RENDERED,
                fn: (storyName) => {
                    service.send('LOADED', { storyName, pinned: pinned_storage_1.getPinned(storyName) });
                },
            },
            {
                eventName: coreEvents.STORY_CHANGED,
                fn: () => service.send('WAIT'),
            },
        ]);
        return unsubscribe;
    }, [service, channel]);
    react_2.useEffect(() => {
        function finishAll({ results }) {
            service.send('FINISH', { results });
        }
        function finishOne({ result }) {
            const results = mergeWithResults({
                existing: service.state.context.current.results,
                result,
            });
            service.send('FINISH', { results });
        }
        const unbindChannel = bind_channel_events_1.bindAll(channel, [
            { eventName: events_1.default.FINISH_ALL, fn: finishAll },
            { eventName: events_1.default.FINISH_ONE, fn: finishOne },
        ]);
        const unsubscribable = service.subscribe(function next(state, event) {
            if (!state.changed) {
                return;
            }
            if (!event) {
                return;
            }
            const { current, storyName } = state.context;
            if (event.type === 'SAVE') {
                file_system_1.saveFile(storyName, current);
                return;
            }
            if (event.type === 'PIN') {
                pinned_storage_1.savePinned(storyName, current);
                return;
            }
            if (event.type === 'UNPIN') {
                pinned_storage_1.clearPinned(storyName);
                return;
            }
            const { samples, copies } = current;
            if (state.matches('active.running')) {
                if (event.type === 'START_ALL') {
                    channel.emit(events_1.default.START_ALL, {
                        samples,
                        copies,
                    });
                    return;
                }
                if (event.type === 'START_ONE') {
                    channel.emit(events_1.default.START_ONE, {
                        taskName: event.taskName,
                        samples,
                        copies,
                    });
                }
            }
        });
        return function unsubscribe() {
            unbindChannel();
            unsubscribable.unsubscribe();
        };
    }, [service, channel]);
    return { state, send, service };
}
exports.default = usePanelMachine;
