"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const get_result_map_1 = __importDefault(require("../util/get-result-map"));
const async_1 = require("./async");
const run_static_task_1 = require("./run-static-task");
const run_timed_task_1 = require("./run-timed-task");
async function runGroup({ group, getElement, samples, }) {
    const staticResults = await async_1.asyncMap({
        source: group.tasks.filter((task) => task.type === 'static'),
        map: async function map(task) {
            return run_static_task_1.getResultForStaticTask({
                task,
                getElement,
            });
        },
    });
    const timedResults = await async_1.asyncMap({
        source: group.tasks.filter((task) => task.type === 'timed'),
        map: async function map(task) {
            return run_timed_task_1.getResultForTimedTask({
                task,
                getElement,
                samples,
            });
        },
    });
    const interactionResults = await async_1.asyncMap({
        source: group.tasks.filter((task) => task.type === 'interaction'),
        map: async function map(task) {
            return run_timed_task_1.getResultForTimedTask({
                task,
                getElement,
                samples,
            });
        },
    });
    const results = {
        groupId: group.groupId,
        map: get_result_map_1.default([...timedResults, ...staticResults, ...interactionResults]),
    };
    return results;
}
exports.default = runGroup;
