"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getResultForTimedTask = void 0;
const async_1 = require("./async");
const get_error_result_1 = __importDefault(require("./get-error-result"));
const mark_1 = __importDefault(require("./mark"));
const print_error_1 = __importDefault(require("./print-error"));
const run_interaction_task_1 = __importDefault(require("./run-interaction-task"));
const with_container_1 = __importDefault(require("./with-container"));
const with_duration_1 = __importDefault(require("./with-duration"));
function getAverage(values) {
    return values.reduce((total, current) => total + current, 0) / values.length;
}
function getStandardDeviation(average, values) {
    const squaredDifferences = values.map((value) => (value - average) ** 2);
    const squareDifferenceAverage = getAverage(squaredDifferences);
    return Math.sqrt(squareDifferenceAverage);
}
function getDifferenceFrom(relativeTo, target) {
    const diff = Math.abs(target - relativeTo);
    return (diff / relativeTo) * 100;
}
function getUpperAndLower(average, values) {
    const ordered = [...values].sort((a, b) => a - b);
    const lowest = ordered[0];
    const highest = ordered[ordered.length - 1];
    return {
        lowerPercentage: getDifferenceFrom(average, lowest),
        upperPercentage: getDifferenceFrom(average, highest),
    };
}
async function runTimedTask({ task, getElement }) {
    return with_container_1.default((container) => {
        return mark_1.default(task.name, () => with_duration_1.default((controls) => task.run({ controls, container, getElement })));
    });
}
async function getResultForTimedTask({ task, getElement, samples, }) {
    try {
        const durations = await async_1.asyncMap({
            source: Array.from({ length: samples }),
            map: async function map() {
                if (task.type === 'timed') {
                    return runTimedTask({
                        task,
                        getElement,
                    });
                }
                return run_interaction_task_1.default({
                    task,
                    getElement,
                });
            },
        });
        const average = getAverage(durations);
        const { upperPercentage, lowerPercentage } = getUpperAndLower(average, durations);
        const standardDeviation = getStandardDeviation(average, durations);
        const result = {
            type: 'timed',
            taskName: task.name,
            averageMs: average,
            samples,
            variance: {
                upperPercentage,
                lowerPercentage,
                standardDeviation,
            },
        };
        return result;
    }
    catch (error) {
        print_error_1.default({ task, error });
        return get_error_result_1.default({ task, error });
    }
}
exports.getResultForTimedTask = getResultForTimedTask;
