"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const tiny_invariant_1 = __importDefault(require("tiny-invariant"));
async function getDuration(fn) {
    const start = performance.now();
    await fn();
    const finish = performance.now();
    return finish - start;
}
async function withDuration(fn) {
    let timedDuration = null;
    let isControlled = false;
    const controls = {
        time: async function time(fn) {
            tiny_invariant_1.default(!isControlled, 'controls.time has already been used');
            isControlled = true;
            timedDuration = await getDuration(fn);
        },
    };
    const wholeTaskDuration = await getDuration(() => fn(controls));
    if (isControlled) {
        tiny_invariant_1.default(timedDuration != null, `
      You have used controls.timed but have not waited for the result to finish
      Ensure that you wait for the result:

      await controls.time(async () => {});

      You might not be waiting for controls.time

      controls.time(async () => {});
    `);
        return timedDuration;
    }
    return wholeTaskDuration;
}
exports.default = withDuration;
