"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getGroups = void 0;
const client_1 = __importDefault(require("./preset/client"));
const server_1 = __importDefault(require("./preset/server"));
const get_interaction_group_1 = require("./get-interaction-group");
const flatten_1 = __importDefault(require("../util/flatten"));
const tiny_invariant_1 = __importDefault(require("tiny-invariant"));
function getDuplicateTaskNames(groups) {
    const tasks = flatten_1.default(groups.map((group) => group.tasks));
    const allNames = tasks.map((task) => task.name);
    const duplicates = allNames.filter((name) => {
        return allNames.filter((value) => value === name).length > 1;
    });
    return [...new Set(duplicates)];
}
function getGroups({ allowedGroups, interactions, }) {
    const result = [];
    if (allowedGroups.includes('server')) {
        result.push(server_1.default);
    }
    if (allowedGroups.includes('client')) {
        const tasks = allowedGroups.includes('server')
            ? client_1.default.tasks
            : client_1.default.tasks.filter((task) => task.name !== 'Hydrate');
        result.push({
            ...client_1.default,
            tasks,
        });
    }
    result.push(get_interaction_group_1.getInteractionGroup(interactions));
    const duplicateNames = getDuplicateTaskNames(result);
    tiny_invariant_1.default(!duplicateNames.length, `Tasks found with duplicate names: [${duplicateNames.join(',')}]`);
    return result;
}
exports.getGroups = getGroups;
