"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const server_1 = __importDefault(require("react-dom/server"));
const gzip_js_1 = __importDefault(require("gzip-js"));
const convert_bytes_to_1 = require("../../util/convert-bytes-to");
const renderToString = {
    type: 'timed',
    name: 'Render to string',
    description: `This task records how long a ReactDOM.renderToString() call takes`,
    run: async ({ getElement }) => {
        server_1.default.renderToString(getElement());
    },
};
const renderToStaticMarkup = {
    type: 'timed',
    name: 'Render to static markup (cannot be hydrated)',
    description: `
    This task records how long a ReactDOM.renderToStaticMarkup() call takes.
    This output cannot be hydrated on the client
  `,
    run: async ({ getElement }) => {
        server_1.default.renderToStaticMarkup(getElement());
    },
};
const getRawStringSizeInKB = {
    type: 'static',
    name: 'String output size',
    description: `
    The size of the string generated by ReactDOM.renderToString().
  `,
    scale: 'kb',
    run: async ({ getElement }) => {
        const output = server_1.default.renderToString(getElement());
        const blob = new Blob([output]);
        return convert_bytes_to_1.bytesToKiloBytes(blob.size);
    },
};
const getGzipStringSizeInKB = {
    type: 'static',
    name: 'String output size (gzip)',
    description: `
    The gzipped size of the string generated by ReactDOM.renderToString().
  `,
    scale: 'kb',
    run: async ({ getElement }) => {
        const output = server_1.default.renderToString(getElement());
        const bytes = gzip_js_1.default.zip(output, { level: 9 }).length;
        return convert_bytes_to_1.bytesToKiloBytes(bytes);
    },
};
const getRawStaticMarkupSizeInKB = {
    type: 'static',
    name: 'Static markup output size',
    description: `
    The size of the string generated by ReactDOM.renderToStaticMarkup().
  `,
    scale: 'kb',
    run: async ({ getElement }) => {
        const output = server_1.default.renderToStaticMarkup(getElement());
        const blob = new Blob([output]);
        return convert_bytes_to_1.bytesToKiloBytes(blob.size);
    },
};
const getGzipStaticMarkupSizeInKB = {
    type: 'static',
    name: 'Static markup output size (gzip)',
    description: `
    The gzipped size of the string generated by ReactDOM.renderToStaticMarkup().
  `,
    scale: 'kb',
    run: async ({ getElement }) => {
        const output = server_1.default.renderToStaticMarkup(getElement());
        const bytes = gzip_js_1.default.zip(output, { level: 9 }).length;
        return convert_bytes_to_1.bytesToKiloBytes(bytes);
    },
};
const group = {
    groupId: 'Server',
    name: 'Server ☁️',
    tasks: [
        renderToString,
        renderToStaticMarkup,
        getRawStringSizeInKB,
        getGzipStringSizeInKB,
        getRawStaticMarkupSizeInKB,
        getGzipStaticMarkupSizeInKB,
    ],
};
exports.default = group;
